-- name:   crtOnlineItems_iSeries.sql
--
-- This file contains SQL commands to create and populate the
-- OnlineItem table for the iSeries database.



create schema ejb;

drop table ejb.OnlineItem;
create table ejb.OnlineItem
(
  ItemTypeId    int NOT NULL,
  CatalogNumber int,
  Title         char(75),
  Description   varchar(2000),
  Value         bigint,
  StartingBid   bigint,
  ImageLocn     varchar(100),
  ImageLocnSm   varchar(100),
  LastBid       bigint,
  LastBidder    varchar(100),
  PRIMARY KEY(ItemTypeId)
);

comment on table ejb.OnlineItem is
'Holds a description of an item that is being auctioned.
It is a subset of table ejb.ItemType';

comment on ejb.OnlineItem
(
  CatalogNumber is 'The number of the item as it appears in the catalog.',
  Title         is 'The title of the item as it appears in the catalog.',
  Description   is 'A glowing description of the item.',
  Value         is 'What the donor considers to be the fair market value
of the item, in cents (USD).  This is a money value.',
  StartingBid   is 'The opening bid cannot be less than this value in cents
(USD).  This is a money value.',
  ImageLocn     is 'Name of an image file, for example, 1234.gif.',
  ImageLocnSm   is 'Name of a small image file, for example, 1234sm.gif.',
  LastBid       is 'The last bid in cents (USD).',
  LastBidder    is 'The name of the last bidder.'
);

drop table ejb.namevalue;
create table ejb.namevalue
(
  name      char(10) not null,
  ivalue    int,
  svalue    char(100),
  primary key(name)
);

comment on table ejb.namevalue is 'This acts like a registry.
It is a way to save some name value pairs.';
comment on ejb.namevalue
(
  name         is 'The name part of the name value pair.',
  ivalue       is 'Used when the value part is an integer.',
  svalue       is 'Used when the value part is a string.'
);


-- load sample data
insert into ejb.OnlineItem values
(
        1, 1, 'Yellow Tulips: Vase of Flowers', 'Crystal handmade vase
with fresh yellow tulips.', 10000, 2000, '3052.gif', '3052sm.gif', null, null
);

insert into ejb.OnlineItem values
(
        2, 2, 'Springtime Flowers', 'Wrought iron pot with fresh springtime
assortment. Included in this beautiful arrangement are rare pink roses and
tropical citrus branches.', 20000, 3500, '3048.gif', '3048sm.gif', null, null
);

insert into ejb.OnlineItem values
(
        3, 3, 'Yellow and Pink Roses in a Vase', 'This superb arrangement
is made of fresh long-stem baby pink and yellow roses. Comes with a
ceramic indigo vase.', 25000, 5000, '3075.gif', '3075sm.gif', null, null
);

